@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
 our $DATE = '2015-08-18'; # DATE
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -45,11 +45,22 @@ sub _scan_prereqs {
             push @files, "$File::Find::dir/$_";
         },
         (grep {-d} (
-            "t", "xt", "lib", "bin", "script", "scripts",
+            "lib", "bin", "script", "scripts",
             #"sample", "samples", "example", "examples" # decidedly not included
             #"share", # decidedly not included
         ))
     );
+    find(
+        sub {
+            return unless -f;
+            return if check_backup_filename(filename=>$_);
+            return unless /\.t$/;
+            push @files, "$File::Find::dir/$_";
+        },
+        (grep {-d} (
+            "t", "xt",
+        ))
+    );
     my %res;
     for my $file (@files) {
         my $scanres = $scanner->scan_file($file);
@@ -315,7 +326,7 @@ App::LintPrereqs - Check extraneous/missing prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.28 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-18.
+This document describes version 0.29 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2015-08-18.
 
 =head1 SYNOPSIS
 
